/**
 * tiansishangwu.com Inc. Copyright (c) 2013-2018 All Rights Reserved.
 */
package com.jqtx.windows.component.tsmodel;

import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.Valid;
import javax.validation.constraints.*;
import java.math.BigDecimal;
import java.util.Date;
import java.util.List;

/**
 * 通过网关接口同步案件请求对象
 *
 * @Description
 * @Author dongxiaoxia
 * @Date 2018/9/12 19:34
 */
@Data
public class AddCaseRequest {

    @NotNull(message = "合作渠道不能为空")
    @Min(value = 1, message = "合作渠道不能为空")
    @ApiModelProperty(value = "合作渠道", required = true)
    private Long bizChannel;

    @Valid
    private List<ContactRequest> contactRequests;

    @Valid
    private List<SimpleAttachRequest> attachments;

    @Valid
    private List<UrgentContactRequest> urgentContactModelList;


    /**
     * 客户基础信息
     */
    @NotBlank(message = "客户姓名不能为空")
    @ApiModelProperty(value = "客户姓名", required = true)
    private String clientName;
    @NotBlank(message = "证件号码不能为空")
    @ApiModelProperty(value = "证件号码", required = true)
    private String clientIdCard;
    @ApiModelProperty(value = "手机号码", required = true)
    private String clientMobile;

    /**
     * 案件基础信息
     */
    @NotBlank(message = "还款卡号不能为空")
    @ApiModelProperty(value = "还款卡号", required = true)
    private String loanBankCard;
    @NotBlank(message = "贷款产品名不能为空")
    @ApiModelProperty(value = "贷款产品名", required = true)
    private String loanName;
    @NotBlank(message = "产品类型不能为空")
    @ApiModelProperty(value = "产品类型", required = true)
    private String productTypeCode;
    @NotBlank(message = "产品类型名称不能为空")
    @ApiModelProperty(value = "产品类型名称", required = true)
    private String productTypeName;
    @NotBlank(message = "借款编号不能为空")
    @ApiModelProperty(value = "借款编号", required = true)
    private String loanNo;
    @NotBlank(message = "委托方案件编号不能为空")
    @ApiModelProperty(value = "委托方案件编号", required = true)
    private String loanCaseNo;
    @ApiModelProperty(value = "放款日期", required = true)
    private Date loanDate;
    @NotNull(message = "还款日期不能为空")
    @ApiModelProperty(value = "还款日期", required = true)
    private Date loanBackDate;
    @Min(value = 1, message = "总期数需要大于等于1")
    @ApiModelProperty(value = "总期数", required = true)
    private Integer loanTotalPeriod;
    @Min(value = 0, message = "剩余期数需要大于等于0")
    @ApiModelProperty(value = "剩余期数", required = true)
    private Integer loanLeftPeriod;
    @Min(value = 1, message = "当前期数需要大于等于1")
    @ApiModelProperty(value = "当前期数", required = true)
    private Integer loanCurrentPeriod;
    @Min(value = 1, message = "当期天数需要大于等于1")
    @ApiModelProperty(value = "当期天数", required = true)
    private Integer loanCurrentPeriodDays;
    @Min(value = 1, message = "委外手数需要大于等于1")
    @ApiModelProperty(value = "委外手数", required = true)
    private Integer loanDelegateTimes;
    @DecimalMin(value = "0.00", message = "委案金额不能为负数")
    @ApiModelProperty(value = "委案金额", required = true)
    private BigDecimal loanDelegateAmt;
    @DecimalMin(value = "0.00", message = "本次借款总金额不能为负数")
    @ApiModelProperty(value = "本次借款总金额", required = true)
    private BigDecimal loanTotalAmt;

    /**
     * 合计金额
     */
    @DecimalMin(value = "0.00", message = "全部应还金额不能为负数")
    @ApiModelProperty(value = "全部应还金额", required = true)
    private BigDecimal totalShouldRepay;
    @DecimalMin(value = "0.00", message = "全部已还金额不能为负数")
    @ApiModelProperty(value = "全部已还金额", required = true)
    private BigDecimal totalBackedRepay;
    @DecimalMin(value = "0.00", message = "全部未还金额不能为负数")
    @ApiModelProperty(value = "全部未还金额", required = true)
    private BigDecimal totalUnBackedRepay;

    /**
     * 本金
     */
  /*@DecimalMin(value = "0.00", message = "全部应还本金不能为负数")
  @ApiModelProperty(value = "全部应还本金", required = true)
  private BigDecimal capitalTotalShouldRepay;*/
  /*@DecimalMin(value = "0.00", message = "全部已还本金不能为负数")
  @ApiModelProperty(value = "全部已还本金", required = true)
  private BigDecimal capitalTotalBackedRepay;*/
    @DecimalMin(value = "0.00", message = "当期应还本金不能为负数")
    @ApiModelProperty(value = "当期应还本金", required = true)
    private BigDecimal capitalPeriodShouldRepay;
    @DecimalMin(value = "0.00", message = "当期已还本金不能为负数")
    @ApiModelProperty(value = "当期已还 本金", required = true)
    private BigDecimal capitalPeriodBackedRepay;

    /**
     * 利息
     */
  /*@DecimalMin(value = "0.00", message = "全部应还利息不能为负数")
  @ApiModelProperty(value = "全部应还利息", required = true)
  private BigDecimal interestTotalShouldRepay;*/
  /*@DecimalMin(value = "0.00", message = "全部已还利息不能为负数")
  @ApiModelProperty(value = "全部已还利息", required = true)
  private BigDecimal interestTotalBackedRepay;*/
    @DecimalMin(value = "0.00", message = "当期应还利息不能为负数")
    @ApiModelProperty(value = "当期应还利息", required = true)
    private BigDecimal interestPeriodShouldRepay;
    @DecimalMin(value = "0.00", message = "当期已还利息不能为负数")
    @ApiModelProperty(value = "当期已还利息", required = true)
    private BigDecimal interestPeriodBackedRepay;

    /**
     * 服务费
     */
  /*@DecimalMin(value = "0.00", message = "全部应还服务费不能为负数")
  @ApiModelProperty(value = "全部应还服务费", required = true)
  private BigDecimal feeTotalShouldRepay;*/
  /*@DecimalMin(value = "0.00", message = "全部已还服务费不能为负数")
  @ApiModelProperty(value = "全部已还服务费", required = true)
  private BigDecimal feeTotalBackedRepay;*/
    @DecimalMin(value = "0.00", message = "当期应还服务费不能为负数")
    @ApiModelProperty(value = "当期应还服务费", required = true)
    private BigDecimal feePeriodShouldRepay;
    @DecimalMin(value = "0.00", message = "当期以已服务费不能为负数")
    @ApiModelProperty(value = "当期已还服务费", required = true)
    private BigDecimal feePeriodBackedRepay;

    /**
     * 罚息
     */
  /*@DecimalMin(value = "0.00", message = "全部应还罚息不能为负数")
  @ApiModelProperty(value = "全部应还罚息", required = true)
  private BigDecimal punishTotalShouldRepay;*/
  /*@DecimalMin(value = "0.00", message = "全部已还罚息不能为负数")
  @ApiModelProperty(value = "全部已还罚息", required = true)
  private BigDecimal punishTotalBackedRepay;*/
    @DecimalMin(value = "0.00", message = "当期应还罚息不能为负数")
    @ApiModelProperty(value = "当期应还罚息", required = true)
    private BigDecimal punishPeriodShouldRepay;
    @DecimalMin(value = "0.00", message = "当期已还罚息不能为负数")
    @ApiModelProperty(value = "当期已还罚息", required = true)
    private BigDecimal punishPeriodBackedRepay;

    /**
     * 客户扩展信息
     */
    @Pattern(regexp = "男|女")
    @ApiModelProperty(value = "性别（男|女）", required = true)
    private String extGender;
    /**
     * 户籍所在地
     */
    @ApiModelProperty(value = "户籍所在地", required = false)
    private String extRegisterAddress;
    /**
     * 现居地地址
     */
    @ApiModelProperty(value = "现居地地址", required = false)
    private String extLiveAddress;
    /**
     * 公司名称
     */
    @ApiModelProperty(value = "公司名称", required = false)
    private String extCompanyName;
    /**
     * 公司地址
     */
    @ApiModelProperty(value = "公司地址", required = false)
    private String extCompanyAddress;
    /**
     * 职位
     */
    @ApiModelProperty(value = "职位", required = false)
    private String extClientJobTitle;
    /**
     * 公司联系电话
     */
    @ApiModelProperty(value = "公司联系电话", required = false)
    private String extCompanyPhone;
    /**
     * 家庭地址
     */
    @ApiModelProperty(value = "家庭地址", required = false)
    private String extHomeAddress;
    /**
     * 备注
     */
    @ApiModelProperty(value = "备注", required = false)
    private String memo;

    @ApiModelProperty(value = "资金渠道", required = false)
    private String fundChannel;

    @ApiModelProperty(value = "bd名字", required = false)
    private String bdName;

}
